@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008 Julien Danjou
--- @release v3.4.11
+-- @release v3.4.13
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -405,7 +405,7 @@ end
 --- Set the client as slave: put it at the end of other windows.
 -- @param c The window to set as slave.
 function setslave(c)
-    local cls = visible(c.screen)
+    local cls = capi.client.get(screen)
     for k, v in pairs(cls) do
         c:swap(v)
     end
@@ -580,9 +580,9 @@ end
 capi.client.add_signal("new", function(c)
     local function store_init_geometry(c)
         property.set(c, "floating_geometry", c:geometry())
-        c:remove_signal("property::geometry", store_init_geometry)
+        c:remove_signal("property::border_width", store_init_geometry)
     end
-    c:add_signal("property::geometry", store_init_geometry)
+    c:add_signal("property::border_width", store_init_geometry)
 end)
 
 capi.client.add_signal("manage", function(c)
@@ -862,6 +862,30 @@ function property.set(c, prop, value)
     c:emit_signal("property::" .. prop)
 end
 
+---
+-- Returns an iterator to cycle through, starting from the client in focus or
+-- the given index, all clients that match a given criteria.
+-- @param filter a function that returns true to indicate a positive match
+-- @param start  what index to start iterating from.  Defaults to using the
+-- index of the currently focused client.
+-- @param s      which screen to use.  nil means all screens.
+-- @usage e.g.: un-minimize all urxvt instances
+-- <p><code>
+-- local urxvt = function (c) <br/>
+-- return awful.rules.match(c, {class = "URxvt"}) <br/>
+-- end <br/>
+-- </br>
+-- for c in awful.client.cycle(urxvt) do <br/>
+-- c.minimized = false <br/>
+-- end <br/>
+-- </code></p>
+function cycle(filter, start, s)
+    local clients = capi.client.get(s)
+    local focused = capi.client.focus
+    local start   = start or util.table.hasitem(clients, focused)
+    return util.table.cycle(clients, filter, start)
+end
+
 -- Register standards signals
 capi.client.add_signal("focus", focus.history.add)
 capi.client.add_signal("unmanage", focus.history.delete)
@@ -872,4 +896,4 @@ capi.client.add_signal("unmanage", urgent.delete)
 
 capi.client.add_signal("unmanage", floating.delete)
 
--- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
+-- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:textwidth=80
