@@ -2,7 +2,7 @@
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @author Sébastien Gross &lt;seb-awesome@chezwam.org&gt;
 -- @copyright 2008 Julien Danjou, Sébastien Gross
--- @release v3.4.11
+-- @release v3.4.13
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -11,6 +11,7 @@ local os = os
 local table = table
 local math = math
 local print = print
+local pairs = pairs
 local util = require("awful.util")
 
 --- Completion module.
@@ -172,11 +173,11 @@ function generic(text, cur_pos, ncomp, keywords)
 
     -- Filter out only keywords starting with text
     local matches = {}
-    table.foreach(keywords, function(_, x)
-        if x:sub(1 , #text) == text then
+    for _, x in pairs(keywords) do
+        if x:sub(1, #text) == text then
             table.insert(matches, x)
         end
-    end)
+    end
 
     -- if there are no matches just leave out with the current text and position
     if #matches == 0 then
@@ -188,4 +189,4 @@ function generic(text, cur_pos, ncomp, keywords)
     return matches[ncomp], #matches[ncomp] + 1, matches
 end
 
--- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
+-- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:textwidth=80
