@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008 Julien Danjou
--- @release v3.4.11
+-- @release v3.4.13
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -89,46 +89,18 @@ function spawn_with_shell(cmd, screen)
     end
 end
 
-local function read_all(fn)
-    local fd = io.open(fn, _OPEN_RT)
-    if not fd then return nil end
-    local str = fd:read'*a'
-    fd:close()
-    return str
-end
-
 --- Read a program output and returns its output as a string.
 -- @param cmd The command to run.
--- @return A string with the program output, or nil if an error occurred.
+-- @return A string with the program output, or the error if one occured.
 function pread(cmd)
     if cmd and cmd ~= "" then
-        local rc, sout
-        local tmp1, tmp2
-        local fd_check, serr_check
-
-        tmp1 = os.tmpname()
-        tmp2 = os.tmpname()
-
-        rc = os.execute(cmd.." > "..tmp1.." 2> "..tmp2)
-
-        if rc == 0 then
-            sout = read_all(tmp1)
+        local f, err = io.popen(cmd, 'r')
+        if f then
+            local s = f:read("*all")
+            f:close()
+            return s
         else
-            return nil
-        end
-
-        fd_check = io.open(tmp2)
-        if not fd_check then return nil end
-        serr_check = fd_check:read'*l'
-        fd_check:close()
-
-        os.remove(tmp1)
-        os.remove(tmp2)
-
-        if serr_check then
-            return nil
-        else
-            return sout
+            return err
         end
     end
 end
@@ -207,7 +179,7 @@ end
 -- It searches for the icon path under the directories given w/the right ext
 -- @param iconname The name of the icon to search for.
 -- @param exts Table of image extensions allowed, otherwise { 'png', gif' }
--- @param dirs Table of dirs to search, otherwise { '/usr/share/pixmaps/' }
+-- @param dirs Table of dirs to search, otherwise { '/usr/local/share/pixmaps/' }
 function geticonpath(iconname, exts, dirs)
     exts = exts or { 'png', 'gif' }
     dirs = dirs or { '/usr/local/share/pixmaps/' }
@@ -391,4 +363,25 @@ function table.clone(t)
     return c
 end
 
--- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
+---
+-- Returns an iterator to cycle through, starting from the first element or the
+-- given index, all elments of a table that match a given criteria.
+-- @param t      the table to iterate
+-- @param filter a function that returns true to indicate a positive match
+-- @param start  what index to start iterating from.  Default is 1 (=> start of
+-- the table)
+function table.cycle(t, filter, start)
+    local count  = 0
+    local index  = start or 1
+    local length = #t
+
+    return function ()
+        while count < length do
+            local item = t[index]
+            index = cycle(#t, index + 1)
+            count = count + 1
+            if filter(item) then return item end
+        end
+    end
+end
+-- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:textwidth=80
