@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008-2009 Julien Danjou
--- @release v3.4.11
+-- @release v3.4.13
 ---------------------------------------------------------------------------
 
 local setmetatable = setmetatable
@@ -20,6 +20,7 @@ function new(args)
     local w = wbutton(args)
     if not w then return end
 
+    local b
     if args.command then
        b = util.table.join(w:buttons(), button({}, 1, nil, function () util.spawn(args.command) end))
     elseif args.menu then
@@ -32,4 +33,4 @@ end
 
 setmetatable(_M, { __call = function (_, ...) return new(...) end })
 
--- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
+-- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:textwidth=80
