@@ -1,7 +1,7 @@
 ----------------------------------------------------------------------------
 -- @author koniu &lt;gkusnierz@gmail.com&gt;
 -- @copyright 2008 koniu
--- @release v3.4.11
+-- @release v3.4.13
 ----------------------------------------------------------------------------
 
 -- Package environment
@@ -484,17 +484,12 @@ if capi.dbus then
                 return
             end
         end
-        local score = 0
         for i, obj in pairs(config.mapping) do
             local filter, preset, s = obj[1], obj[2], 0
             if (not filter.urgency or filter.urgency == hints.urgency) and
                (not filter.category or filter.category == hints.category) and
                (not filter.appname or filter.appname == appname) then
-                for j, el in pairs(filter) do s = s + 1 end
-                if s > score then
-                    score = s
-                    args.preset = preset
-                end
+                   args.preset = util.table.join(args.preset, preset)
             end
         end
         if not args.preset.callback or (type(args.preset.callback) == "function" and
@@ -601,4 +596,4 @@ if capi.dbus then
     capi.dbus.request_name("session", "org.freedesktop.Notifications")
 end
 
--- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
+-- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:textwidth=80
